import pandas as pd
import numpy as np
import scipy.stats as st
import pystan
dmgDat = pd.read_csv('/Users/Nate/Documents/FIU/Research/Gap_Dynamics/Data/GrowingSeason_2012_Data/HerbDmg_Fall2012.csv')
dmgDat = dmgDat[dmgDat['treatment']!='SIGEO']
dmgPlot = dmgDat.groupby(['plot', 'treatment'])['avgPctDmg'].mean()
dmgTreat = dmgPlot.groupby(level='treatment').agg({'mean': lambda x: x.mean(), 'SE': lambda x: x.std()/np.sqrt(x.count())})

cat1 = dmgPlot.xs('Control', level='treatment')
cat2 = dmgPlot.xs('Pesticide', level='treatment')

tMod = """
data{
	int N;
	vector[N] g1;
	vector[N] g2;
}
parameters{
	real mu1;
	real mu2;
	real sd_y;
}
model{
	g1 ~ normal(mu1, sd_y);
	g2 ~ normal(mu2, sd_y);
}
generated quantities{
	real diff;
	diff <- mu1 - mu2;
}
"""
compMod = pystan.StanModel(model_code=tMod)

data = {'N': 6, 'g1': cat1, 'g2': cat2}
fittedMod = compMod.sampling(data=data, iter=50000, chains=4, thin=10)
diff = fittedMod.extract('diff')['diff']
print np.mean(diff > 0)


dmgDat_sp = dmgDat[dmgDat['spCode'].isin(['Litu', 'List2', 'Fagr', 'Fram', 'Acru'])]
dmgPlot_sp = dmgDat_sp.groupby(['plot', 'treatment', 'spCode'])['avgPctDmg'].mean()
dmgTreat_sp = dmgPlot_sp.groupby(level=['treatment', 'spCode']).agg({'mean': lambda x: x.mean(), 'SE': lambda x: x.std()/np.sqrt(x.count())})
